@@ -261,7 +261,7 @@ def describe_file(remote_full_path, req_url, local_full_path=None,
                     code = 0
                     err = '操作成功'
                     if return_file:
-                        with open(local_full_path, "rb") as f:
+                        with open(recovery_full_path, "rb") as f:
                             ret_file = f.read()
                     else:
                         ret_file = ""
